﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Malovani
{
    public partial class Window : Form
    {
        private Color initColor = Color.Yellow;
        private Color previewColor = Color.RoyalBlue;

        private Pen pen = new Pen (Color.Orange);
        private Brush brush = new SolidBrush (Color.Gray);

        private int X0, Y0;
        private bool stisk = false;
        private Bitmap save;

        private void paint (MouseEventArgs e, Pen p, Brush b)
        {
            Graphics g = Graphics.FromImage(pictureBox.Image);
            g.DrawImage(save, 0, 0);

            if (e.Button == MouseButtons.Right)
            {
                int X1 = e.X;
                int Y1 = e.Y;

                int X = Math.Min(X0, X1);
                int Y = Math.Min(Y0, Y1);
                int W = Math.Abs(X0 - X1);
                int H = Math.Abs(Y0 - Y1);

                // if (b != null)
                g.FillRectangle(b, X, Y, W, H);
                g.DrawRectangle(p, X, Y, W, H);
            }
            else if (e.Button == MouseButtons.Middle)
            {
                // if (b != null)
                g.FillEllipse(b, X0, Y0, e.X - X0, e.Y - Y0);
                g.DrawEllipse(p, X0, Y0, e.X - X0, e.Y - Y0);
            }
            else
            {
                g.DrawLine(p, X0, Y0, e.X, e.Y);
            }

            pictureBox.Invalidate();
        }
        
        public Window()
        {
            InitializeComponent();
            pictureBox.Image = new Bitmap
                (pictureBox.Width, pictureBox.Height);

            Graphics g = Graphics.FromImage (pictureBox.Image);
            Brush b = new SolidBrush (initColor);
            g.FillRectangle (b, 0, 0, pictureBox.Width, pictureBox.Height);
        }

        private void testMenu_Click(object sender, EventArgs e)
        {
            Graphics g = Graphics.FromImage(pictureBox.Image);
            Pen p  = new Pen (Color.Red);
            p.Width = 3;
            g.DrawLine (p, 10, 10, 100, 100);


            for (int i = 0; i < 8; i++)
                for (int j = 0; j < 8; j++)
                {
                    const int K = 20;
                    g.DrawRectangle (pen, K*i, K*j, K-2, K-2);
                }

            pictureBox.Invalidate ();
        }

        private void quitMenu_Click(object sender, EventArgs e)
        {
            Close ();
        }

        private void pictureBox_MouseDown(object sender, 
                                          MouseEventArgs e)
        {
            X0 = e.X;
            Y0 = e.Y;
            stisk = true;
            save = new Bitmap (pictureBox.Image);
        }

        private void pictureBox_MouseMove(object sender, MouseEventArgs e)
        {
            if (stisk)
            {
                Pen p = new Pen (previewColor);
                Brush b = new SolidBrush (Color.FromArgb(0,0,0,0));
                paint (e, p, b);
            }
        }

        private void pictureBox_MouseUp(object sender, MouseEventArgs e)
        {
            if (stisk)
            {
               paint (e, pen, brush);
               stisk = false;
               save = null;
            }
        }

        private void pictureBox_Resize(object sender, EventArgs e)
        {
        }

        private static int max(int a, int b)
        {
            return a > b ? a : b;
        }

        private void pictureBox_SizeChanged(object sender, EventArgs e)
        {
            Size s1 = pictureBox.Size;
            Size s2 = pictureBox.Image.Size;
            int W = max(s1.Width, s2.Width);
            int H = max(s1.Height, s2.Height);
            Bitmap b = new Bitmap(W, H);

            Graphics g = Graphics.FromImage(b);
            Brush br = new SolidBrush(initColor);
            g.FillRectangle(br, 0, 0, pictureBox.Width, pictureBox.Height);
            g.DrawImage(pictureBox.Image, 0, 0);
            pictureBox.Image = b;
        }

        private void colorPanel1_MouseDown(object sender, MouseEventArgs e)
        {
            Panel panel = (sender as Panel);
            Color color = panel.BackColor;

            if (e.Button == MouseButtons.Left)
                pen = new Pen(color);
            else if (e.Button == MouseButtons.Right)
                brush = new SolidBrush(color);
            else if (e.Button == MouseButtons.Middle)
            {
                // DialogResult result = colorDialog.ShowDialog();
                // if (result == DialogResult.OK)
                if (colorDialog.ShowDialog () == DialogResult.OK)
                {
                    panel.BackColor = colorDialog.Color;
                    pen = new Pen (colorDialog.Color);
                }
            }

        }

        private int cnt = 3;

        private void addPanelMenu_Click(object sender, EventArgs e)
        {
            cnt ++;
            int dist = colorPanel2.Left - colorPanel1.Left - colorPanel1.Width;
            Panel p = new Panel ();
            p.Width = colorPanel1.Width;
            p.Height = colorPanel1.Height;
            p.Top = colorPanel1.Top;
            p.Left = colorPanel1.Left + (cnt-1) * (colorPanel1.Width + dist);
            p.BackColor = Color.Green;
            // toolPanel.Controls.Add (p);
            p.Parent = toolPanel;
            p.MouseDown += colorPanel1_MouseDown;
        }

    }
}
